==> kports-0.8.1.tar.bz2: kports-0.8.1/src/kportsicons.cpp <==
/***************************************************************************
 *   Copyright (C) 2005-2009 by Hannes Hauswedell                          *
 *   kports@soulrebel.in-berlin.de                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 
#include "kportsicons.h"
#include <QFile>
#include <QSettings>

KPortsIcons KPortsIcons::iconLoader;

KPortsIcons::KPortsIcons()
{
 /*   map.insert("folder",    "filesystems/folder");
    map.insert("package",   "mimetypes/application_x_compressed_tar");
    map.insert("list",      "actions/list");
    map.insert("plus",      "actions/list_add");
    map.insert("minus",     "actions/list_remove");
    map.insert("network",   "actions/network");
    map.insert("tag",       "actions/rss_tag");
    map.insert("hd",        "devices/drive_harddisk");
    map.insert("lock",      "actions/encrypted");
    map.insert("1uparrow",  "actions/1uparrow");
    map.insert("statistics", "actions/view_statistics");
    map.insert("find",      "actions/find");
    map.insert("filefind",  "actions/filefind");
    map.insert("clear",     "actions/edit_clear_locationbar");
    map.insert("about",     "actions/messagebox_info");
    map.insert("warning",   "actions/messagebox_warning");
    map.insert("exit",      "actions/exit");
    map.insert("configure", "actions/configure");
    map.insert("flag",      "actions/flag_red");*/
    iconcats << "actions" << "places" << "apps" << "categories" 
             << "devices" << "status" << "emotes" << "mimetypes";

    QSettings settings("kports", "kports");
    path = settings.value("icons/iconsetpath",
                        QString(PREFIX) + "/kde4/share/icons/default.kde4/").toString();
}


KPortsIcons::~KPortsIcons()
{
}


QIcon KPortsIcons::loadIcon(const QString& key)
{
    if (iconCache.contains(key))
        return iconCache[key];

    QIcon   icon;
    QString comp;
/*    if (!map.contains(key))
    {
        //TODO fix this
       for (QMap<QString,QString>::iterator i = map.begin(); i != map.end(); ++i)
            if (i->section('/',-1,-1) == key)
                comp = i;
        if (comp.isEmpty())
            return icon;
    } else
        comp = map[key];*/


//    QString path(":/icons/icons/");
    
    if (key.contains("/"))
    {
        if (QFile::exists(path + "16x16/" + key + ".png"))
            comp = key;
    } else
    {
        foreach(QString cat, iconcats)
            if (QFile::exists(path + "16x16/" + cat +"/" + key + ".png"))
                comp = cat + "/" + key;
    }

    if (comp.isEmpty())
        return icon;


    icon.addFile(path + "16x16/" + comp + ".png", QSize(16,16) );
    icon.addFile(path + "22x22/" + comp + ".png", QSize(22,22) );
    icon.addFile(path + "32x32/" + comp + ".png", QSize(32,32) );
    icon.addFile(path + "48x48/" + comp + ".png", QSize(48,48) );

    iconCache.insert(key, icon);

    return icon;
}

==> kports-0.8.2.tar.bz2: kports-0.8.2/src/kportsicons.cpp <==
/***************************************************************************
 *   Copyright (C) 2005-2009 by Hannes Hauswedell                          *
 *   kports@soulrebel.in-berlin.de                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 
#include "kportsicons.h"
#include <QFile>
#include <QSettings>
#include <QDebug>

KPortsIcons KPortsIcons::iconLoader;

KPortsIcons::KPortsIcons()
{
 /*   map.insert("folder",    "filesystems/folder");
    map.insert("package",   "mimetypes/application_x_compressed_tar");
    map.insert("list",      "actions/list");
    map.insert("plus",      "actions/list_add");
    map.insert("minus",     "actions/list_remove");
    map.insert("network",   "actions/network");
    map.insert("tag",       "actions/rss_tag");
    map.insert("hd",        "devices/drive_harddisk");
    map.insert("lock",      "actions/encrypted");
    map.insert("1uparrow",  "actions/1uparrow");
    map.insert("statistics", "actions/view_statistics");
    map.insert("find",      "actions/find");
    map.insert("filefind",  "actions/filefind");
    map.insert("clear",     "actions/edit_clear_locationbar");
    map.insert("about",     "actions/messagebox_info");
    map.insert("warning",   "actions/messagebox_warning");
    map.insert("exit",      "actions/exit");
    map.insert("configure", "actions/configure");
    map.insert("flag",      "actions/flag_red");*/
    iconcats << "actions" << "places" << "apps" << "categories" 
             << "devices" << "status" << "emotes" << "mimetypes";

    QSettings settings("kports", "kports");
    path = settings.value("icons/iconsetpath",
                        QString(PREFIX) + "/kde4/share/icons/default.kde4/").toString();
    if (!path.endsWith("/"))
        path.append("/");
}


KPortsIcons::~KPortsIcons()
{
}


QIcon KPortsIcons::loadIcon(const QString& key)
{
    if (iconCache.contains(key))
        return iconCache[key];

    QIcon   icon;
    QString comp;
/*    if (!map.contains(key))
    {
        //TODO fix this
       for (QMap<QString,QString>::iterator i = map.begin(); i != map.end(); ++i)
            if (i->section('/',-1,-1) == key)
                comp = i;
        if (comp.isEmpty())
            return icon;
    } else
        comp = map[key];*/


//    QString path(":/icons/icons/");
    
    if (key.contains("/"))
    {
        if (QFile::exists(path + "16x16/" + key + ".png"))
            comp = key;
    } else
    {    
        foreach(QString cat, iconcats)
        {
            if (QFile::exists(path + "16x16/" + cat + "/" + key + ".png"))
                comp = cat + "/" + key;
//             else
//                 qDebug() << "ICONLOADER couldn't find an icon for: "
//                          << path << "16x16/" << cat << "/" << key << ".png";
        }
    }
    if (comp.isEmpty())
    {
        qDebug() << "ICONLOADER couldn't find an icon for: " << key;
        return icon;
    }

    icon.addFile(path + "16x16/" + comp + ".png", QSize(16,16) );
    if (QFile::exists(path + "22x22/" + comp + ".png"))
        icon.addFile(path + "22x22/" + comp + ".png", QSize(22,22) );
    if (QFile::exists(path + "32x32/" + comp + ".png"))
        icon.addFile(path + "32x32/" + comp + ".png", QSize(32,32) );
    if (QFile::exists(path + "48x48/" + comp + ".png"))
        icon.addFile(path + "48x48/" + comp + ".png", QSize(48,48) );

    iconCache.insert(key, icon);

    return icon;
}
